utils::globalVariables(c("r", "label", "Marker", "theo", "Positive", "anchor",
                         "counted", "xloc", "yloc", "XMin", "XMax",
                         "YMin", "YMax", "Var1", "Var2", "Theoretical CSR",
                         "iter", "Permuted K", "Permuted G", "Permuted CSR",
                         "Observed G", "Observed K", "Observed", ":=", ".", "is", 
                         'Exact CSR', 'Label', 'Var3', 'across', 'areapp', 
                         'bind_rows', 'dist', 'distinct', 'mutate',
                         'relocate', 'rename', 'select', 'un'))